# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifyV1Integration:

    swagger_types = {
    
        'additional_line_item_data': 'list[ShopifyAdditionalLineItemData]',
        'allow_invoice_download': 'bool',
        'allow_payment_with_tax_discrepancy': 'bool',
        'allowed_payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'currency': 'str',
        'id': 'int',
        'integrated_payment_form_enabled': 'bool',
        'language': 'str',
        'login_name': 'str',
        'name': 'str',
        'payment_app_version': 'ShopifyIntegrationPaymentAppVersion',
        'payment_installed': 'bool',
        'payment_proxy_path': 'str',
        'planned_purge_date': 'datetime',
        'replace_payment_method_image': 'bool',
        'shop_name': 'str',
        'show_payment_information': 'bool',
        'show_subscription_information': 'bool',
        'space_id': 'int',
        'space_view_id': 'int',
        'state': 'CreationEntityState',
        'subscription_app_version': 'ShopifyIntegrationSubscriptionAppVersion',
        'subscription_installed': 'bool',
        'subscription_proxy_path': 'str',
        'version': 'int',
    }

    attribute_map = {
        'additional_line_item_data': 'additionalLineItemData','allow_invoice_download': 'allowInvoiceDownload','allow_payment_with_tax_discrepancy': 'allowPaymentWithTaxDiscrepancy','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','currency': 'currency','id': 'id','integrated_payment_form_enabled': 'integratedPaymentFormEnabled','language': 'language','login_name': 'loginName','name': 'name','payment_app_version': 'paymentAppVersion','payment_installed': 'paymentInstalled','payment_proxy_path': 'paymentProxyPath','planned_purge_date': 'plannedPurgeDate','replace_payment_method_image': 'replacePaymentMethodImage','shop_name': 'shopName','show_payment_information': 'showPaymentInformation','show_subscription_information': 'showSubscriptionInformation','space_id': 'spaceId','space_view_id': 'spaceViewId','state': 'state','subscription_app_version': 'subscriptionAppVersion','subscription_installed': 'subscriptionInstalled','subscription_proxy_path': 'subscriptionProxyPath','version': 'version',
    }

    
    _additional_line_item_data = None
    _allow_invoice_download = None
    _allow_payment_with_tax_discrepancy = None
    _allowed_payment_method_configurations = None
    _currency = None
    _id = None
    _integrated_payment_form_enabled = None
    _language = None
    _login_name = None
    _name = None
    _payment_app_version = None
    _payment_installed = None
    _payment_proxy_path = None
    _planned_purge_date = None
    _replace_payment_method_image = None
    _shop_name = None
    _show_payment_information = None
    _show_subscription_information = None
    _space_id = None
    _space_view_id = None
    _state = None
    _subscription_app_version = None
    _subscription_installed = None
    _subscription_proxy_path = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.additional_line_item_data = kwargs.get('additional_line_item_data', None)
        self.allow_invoice_download = kwargs.get('allow_invoice_download', None)
        self.allow_payment_with_tax_discrepancy = kwargs.get('allow_payment_with_tax_discrepancy', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.currency = kwargs.get('currency', None)
        self.id = kwargs.get('id', None)
        self.integrated_payment_form_enabled = kwargs.get('integrated_payment_form_enabled', None)
        self.language = kwargs.get('language', None)
        self.login_name = kwargs.get('login_name', None)
        self.name = kwargs.get('name', None)
        self.payment_app_version = kwargs.get('payment_app_version', None)
        self.payment_installed = kwargs.get('payment_installed', None)
        self.payment_proxy_path = kwargs.get('payment_proxy_path', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.replace_payment_method_image = kwargs.get('replace_payment_method_image', None)
        self.shop_name = kwargs.get('shop_name', None)
        self.show_payment_information = kwargs.get('show_payment_information', None)
        self.show_subscription_information = kwargs.get('show_subscription_information', None)
        self.space_id = kwargs.get('space_id', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.subscription_app_version = kwargs.get('subscription_app_version', None)
        self.subscription_installed = kwargs.get('subscription_installed', None)
        self.subscription_proxy_path = kwargs.get('subscription_proxy_path', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def additional_line_item_data(self):
        """Gets the additional_line_item_data of this ShopifyV1Integration.

            

        :return: The additional_line_item_data of this ShopifyV1Integration.
        :rtype: list[ShopifyAdditionalLineItemData]
        """
        return self._additional_line_item_data

    @additional_line_item_data.setter
    def additional_line_item_data(self, additional_line_item_data):
        """Sets the additional_line_item_data of this ShopifyV1Integration.

            

        :param additional_line_item_data: The additional_line_item_data of this ShopifyV1Integration.
        :type: list[ShopifyAdditionalLineItemData]
        """

        self._additional_line_item_data = additional_line_item_data
    
    @property
    def allow_invoice_download(self):
        """Gets the allow_invoice_download of this ShopifyV1Integration.

            

        :return: The allow_invoice_download of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._allow_invoice_download

    @allow_invoice_download.setter
    def allow_invoice_download(self, allow_invoice_download):
        """Sets the allow_invoice_download of this ShopifyV1Integration.

            

        :param allow_invoice_download: The allow_invoice_download of this ShopifyV1Integration.
        :type: bool
        """

        self._allow_invoice_download = allow_invoice_download
    
    @property
    def allow_payment_with_tax_discrepancy(self):
        """Gets the allow_payment_with_tax_discrepancy of this ShopifyV1Integration.

            If in the merchant Shopify store is used legacy tax service, rounding discrepancies in line item tax amounts may occur. When this check is enabled, such discrepancies are tolerated, allowing the payment to proceed without raising an exception.

        :return: The allow_payment_with_tax_discrepancy of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._allow_payment_with_tax_discrepancy

    @allow_payment_with_tax_discrepancy.setter
    def allow_payment_with_tax_discrepancy(self, allow_payment_with_tax_discrepancy):
        """Sets the allow_payment_with_tax_discrepancy of this ShopifyV1Integration.

            If in the merchant Shopify store is used legacy tax service, rounding discrepancies in line item tax amounts may occur. When this check is enabled, such discrepancies are tolerated, allowing the payment to proceed without raising an exception.

        :param allow_payment_with_tax_discrepancy: The allow_payment_with_tax_discrepancy of this ShopifyV1Integration.
        :type: bool
        """

        self._allow_payment_with_tax_discrepancy = allow_payment_with_tax_discrepancy
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this ShopifyV1Integration.

            

        :return: The allowed_payment_method_configurations of this ShopifyV1Integration.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this ShopifyV1Integration.

            

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this ShopifyV1Integration.
        :type: list[PaymentMethodConfiguration]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def currency(self):
        """Gets the currency of this ShopifyV1Integration.

            

        :return: The currency of this ShopifyV1Integration.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ShopifyV1Integration.

            

        :param currency: The currency of this ShopifyV1Integration.
        :type: str
        """

        self._currency = currency
    
    @property
    def id(self):
        """Gets the id of this ShopifyV1Integration.

            A unique identifier for the object.

        :return: The id of this ShopifyV1Integration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifyV1Integration.

            A unique identifier for the object.

        :param id: The id of this ShopifyV1Integration.
        :type: int
        """

        self._id = id
    
    @property
    def integrated_payment_form_enabled(self):
        """Gets the integrated_payment_form_enabled of this ShopifyV1Integration.

            Enabling the integrated payment form will embed the payment form in the Shopify shop. The app needs to be installed for this to be possible.

        :return: The integrated_payment_form_enabled of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._integrated_payment_form_enabled

    @integrated_payment_form_enabled.setter
    def integrated_payment_form_enabled(self, integrated_payment_form_enabled):
        """Sets the integrated_payment_form_enabled of this ShopifyV1Integration.

            Enabling the integrated payment form will embed the payment form in the Shopify shop. The app needs to be installed for this to be possible.

        :param integrated_payment_form_enabled: The integrated_payment_form_enabled of this ShopifyV1Integration.
        :type: bool
        """

        self._integrated_payment_form_enabled = integrated_payment_form_enabled
    
    @property
    def language(self):
        """Gets the language of this ShopifyV1Integration.

            The checkout language forces a specific language in the checkout. Without a checkout language the browser setting of the buyer is used to determine the language.

        :return: The language of this ShopifyV1Integration.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ShopifyV1Integration.

            The checkout language forces a specific language in the checkout. Without a checkout language the browser setting of the buyer is used to determine the language.

        :param language: The language of this ShopifyV1Integration.
        :type: str
        """

        self._language = language
    
    @property
    def login_name(self):
        """Gets the login_name of this ShopifyV1Integration.

            The login name is used to link a specific Shopify payment gateway to this integration.This login name is to be filled into the appropriate field in the shop's payment gateway configuration.

        :return: The login_name of this ShopifyV1Integration.
        :rtype: str
        """
        return self._login_name

    @login_name.setter
    def login_name(self, login_name):
        """Sets the login_name of this ShopifyV1Integration.

            The login name is used to link a specific Shopify payment gateway to this integration.This login name is to be filled into the appropriate field in the shop's payment gateway configuration.

        :param login_name: The login_name of this ShopifyV1Integration.
        :type: str
        """
        if login_name is not None and len(login_name) > 100:
            raise ValueError("Invalid value for `login_name`, length must be less than or equal to `100`")

        self._login_name = login_name
    
    @property
    def name(self):
        """Gets the name of this ShopifyV1Integration.

            The integration name is used internally to identify a specific integration.For example the name is used withinsearch fields and hence it should be distinct and descriptive.

        :return: The name of this ShopifyV1Integration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShopifyV1Integration.

            The integration name is used internally to identify a specific integration.For example the name is used withinsearch fields and hence it should be distinct and descriptive.

        :param name: The name of this ShopifyV1Integration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_app_version(self):
        """Gets the payment_app_version of this ShopifyV1Integration.

            

        :return: The payment_app_version of this ShopifyV1Integration.
        :rtype: ShopifyIntegrationPaymentAppVersion
        """
        return self._payment_app_version

    @payment_app_version.setter
    def payment_app_version(self, payment_app_version):
        """Sets the payment_app_version of this ShopifyV1Integration.

            

        :param payment_app_version: The payment_app_version of this ShopifyV1Integration.
        :type: ShopifyIntegrationPaymentAppVersion
        """

        self._payment_app_version = payment_app_version
    
    @property
    def payment_installed(self):
        """Gets the payment_installed of this ShopifyV1Integration.

            

        :return: The payment_installed of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._payment_installed

    @payment_installed.setter
    def payment_installed(self, payment_installed):
        """Sets the payment_installed of this ShopifyV1Integration.

            

        :param payment_installed: The payment_installed of this ShopifyV1Integration.
        :type: bool
        """

        self._payment_installed = payment_installed
    
    @property
    def payment_proxy_path(self):
        """Gets the payment_proxy_path of this ShopifyV1Integration.

            Define the path of the proxy URL. This only needs to be changed if the app's proxy URL is overwritten in the Shopify store.

        :return: The payment_proxy_path of this ShopifyV1Integration.
        :rtype: str
        """
        return self._payment_proxy_path

    @payment_proxy_path.setter
    def payment_proxy_path(self, payment_proxy_path):
        """Sets the payment_proxy_path of this ShopifyV1Integration.

            Define the path of the proxy URL. This only needs to be changed if the app's proxy URL is overwritten in the Shopify store.

        :param payment_proxy_path: The payment_proxy_path of this ShopifyV1Integration.
        :type: str
        """

        self._payment_proxy_path = payment_proxy_path
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ShopifyV1Integration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this ShopifyV1Integration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ShopifyV1Integration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this ShopifyV1Integration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def replace_payment_method_image(self):
        """Gets the replace_payment_method_image of this ShopifyV1Integration.

            

        :return: The replace_payment_method_image of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._replace_payment_method_image

    @replace_payment_method_image.setter
    def replace_payment_method_image(self, replace_payment_method_image):
        """Sets the replace_payment_method_image of this ShopifyV1Integration.

            

        :param replace_payment_method_image: The replace_payment_method_image of this ShopifyV1Integration.
        :type: bool
        """

        self._replace_payment_method_image = replace_payment_method_image
    
    @property
    def shop_name(self):
        """Gets the shop_name of this ShopifyV1Integration.

            The store address is used to link a specific Shopify shop to this integration. This is the name used in the Shopify's admin URL: [storeAddress].myshopify.com

        :return: The shop_name of this ShopifyV1Integration.
        :rtype: str
        """
        return self._shop_name

    @shop_name.setter
    def shop_name(self, shop_name):
        """Sets the shop_name of this ShopifyV1Integration.

            The store address is used to link a specific Shopify shop to this integration. This is the name used in the Shopify's admin URL: [storeAddress].myshopify.com

        :param shop_name: The shop_name of this ShopifyV1Integration.
        :type: str
        """
        if shop_name is not None and len(shop_name) > 100:
            raise ValueError("Invalid value for `shop_name`, length must be less than or equal to `100`")

        self._shop_name = shop_name
    
    @property
    def show_payment_information(self):
        """Gets the show_payment_information of this ShopifyV1Integration.

            

        :return: The show_payment_information of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._show_payment_information

    @show_payment_information.setter
    def show_payment_information(self, show_payment_information):
        """Sets the show_payment_information of this ShopifyV1Integration.

            

        :param show_payment_information: The show_payment_information of this ShopifyV1Integration.
        :type: bool
        """

        self._show_payment_information = show_payment_information
    
    @property
    def show_subscription_information(self):
        """Gets the show_subscription_information of this ShopifyV1Integration.

            

        :return: The show_subscription_information of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._show_subscription_information

    @show_subscription_information.setter
    def show_subscription_information(self, show_subscription_information):
        """Sets the show_subscription_information of this ShopifyV1Integration.

            

        :param show_subscription_information: The show_subscription_information of this ShopifyV1Integration.
        :type: bool
        """

        self._show_subscription_information = show_subscription_information
    
    @property
    def space_id(self):
        """Gets the space_id of this ShopifyV1Integration.

            

        :return: The space_id of this ShopifyV1Integration.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this ShopifyV1Integration.

            

        :param space_id: The space_id of this ShopifyV1Integration.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this ShopifyV1Integration.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this ShopifyV1Integration.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this ShopifyV1Integration.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this ShopifyV1Integration.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this ShopifyV1Integration.

            The object's current state.

        :return: The state of this ShopifyV1Integration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifyV1Integration.

            The object's current state.

        :param state: The state of this ShopifyV1Integration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def subscription_app_version(self):
        """Gets the subscription_app_version of this ShopifyV1Integration.

            

        :return: The subscription_app_version of this ShopifyV1Integration.
        :rtype: ShopifyIntegrationSubscriptionAppVersion
        """
        return self._subscription_app_version

    @subscription_app_version.setter
    def subscription_app_version(self, subscription_app_version):
        """Sets the subscription_app_version of this ShopifyV1Integration.

            

        :param subscription_app_version: The subscription_app_version of this ShopifyV1Integration.
        :type: ShopifyIntegrationSubscriptionAppVersion
        """

        self._subscription_app_version = subscription_app_version
    
    @property
    def subscription_installed(self):
        """Gets the subscription_installed of this ShopifyV1Integration.

            

        :return: The subscription_installed of this ShopifyV1Integration.
        :rtype: bool
        """
        return self._subscription_installed

    @subscription_installed.setter
    def subscription_installed(self, subscription_installed):
        """Sets the subscription_installed of this ShopifyV1Integration.

            

        :param subscription_installed: The subscription_installed of this ShopifyV1Integration.
        :type: bool
        """

        self._subscription_installed = subscription_installed
    
    @property
    def subscription_proxy_path(self):
        """Gets the subscription_proxy_path of this ShopifyV1Integration.

            Define the path of the proxy URL. This only needs to be changed if the app's proxy URL is overwritten in the Shopify store.

        :return: The subscription_proxy_path of this ShopifyV1Integration.
        :rtype: str
        """
        return self._subscription_proxy_path

    @subscription_proxy_path.setter
    def subscription_proxy_path(self, subscription_proxy_path):
        """Sets the subscription_proxy_path of this ShopifyV1Integration.

            Define the path of the proxy URL. This only needs to be changed if the app's proxy URL is overwritten in the Shopify store.

        :param subscription_proxy_path: The subscription_proxy_path of this ShopifyV1Integration.
        :type: str
        """

        self._subscription_proxy_path = subscription_proxy_path
    
    @property
    def version(self):
        """Gets the version of this ShopifyV1Integration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ShopifyV1Integration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ShopifyV1Integration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ShopifyV1Integration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifyV1Integration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifyV1Integration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppConnector:

    swagger_types = {
    
        'authorization_timeout': 'str',
        'completion_configuration': 'PaymentAppCompletionConfiguration',
        'connector_configuration': 'PaymentConnectorConfiguration',
        'created_on': 'datetime',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'payment_page_endpoint': 'str',
        'processor': 'PaymentAppProcessor',
        'refund_configuration': 'PaymentAppRefundConfiguration',
        'state': 'PaymentAppConnectorState',
        'updated_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'authorization_timeout': 'authorizationTimeout','completion_configuration': 'completionConfiguration','connector_configuration': 'connectorConfiguration','created_on': 'createdOn','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','payment_page_endpoint': 'paymentPageEndpoint','processor': 'processor','refund_configuration': 'refundConfiguration','state': 'state','updated_on': 'updatedOn','version': 'version',
    }

    
    _authorization_timeout = None
    _completion_configuration = None
    _connector_configuration = None
    _created_on = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _name = None
    _payment_page_endpoint = None
    _processor = None
    _refund_configuration = None
    _state = None
    _updated_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.authorization_timeout = kwargs.get('authorization_timeout', None)
        self.completion_configuration = kwargs.get('completion_configuration', None)
        self.connector_configuration = kwargs.get('connector_configuration', None)
        self.created_on = kwargs.get('created_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.payment_page_endpoint = kwargs.get('payment_page_endpoint', None)
        self.processor = kwargs.get('processor', None)
        self.refund_configuration = kwargs.get('refund_configuration', None)
        self.state = kwargs.get('state', None)
        self.updated_on = kwargs.get('updated_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def authorization_timeout(self):
        """Gets the authorization_timeout of this PaymentAppConnector.

            The duration within which the authorization process for a payment should complete.

        :return: The authorization_timeout of this PaymentAppConnector.
        :rtype: str
        """
        return self._authorization_timeout

    @authorization_timeout.setter
    def authorization_timeout(self, authorization_timeout):
        """Sets the authorization_timeout of this PaymentAppConnector.

            The duration within which the authorization process for a payment should complete.

        :param authorization_timeout: The authorization_timeout of this PaymentAppConnector.
        :type: str
        """

        self._authorization_timeout = authorization_timeout
    
    @property
    def completion_configuration(self):
        """Gets the completion_configuration of this PaymentAppConnector.

            The completion configuration controlling how deferred completion is processed. If not present, deferred completion is not supported for this connector.

        :return: The completion_configuration of this PaymentAppConnector.
        :rtype: PaymentAppCompletionConfiguration
        """
        return self._completion_configuration

    @completion_configuration.setter
    def completion_configuration(self, completion_configuration):
        """Sets the completion_configuration of this PaymentAppConnector.

            The completion configuration controlling how deferred completion is processed. If not present, deferred completion is not supported for this connector.

        :param completion_configuration: The completion_configuration of this PaymentAppConnector.
        :type: PaymentAppCompletionConfiguration
        """

        self._completion_configuration = completion_configuration
    
    @property
    def connector_configuration(self):
        """Gets the connector_configuration of this PaymentAppConnector.

            The connector configuration created alongside the connector within its designated space. This configuration is used in transactions created using this connector.

        :return: The connector_configuration of this PaymentAppConnector.
        :rtype: PaymentConnectorConfiguration
        """
        return self._connector_configuration

    @connector_configuration.setter
    def connector_configuration(self, connector_configuration):
        """Sets the connector_configuration of this PaymentAppConnector.

            The connector configuration created alongside the connector within its designated space. This configuration is used in transactions created using this connector.

        :param connector_configuration: The connector_configuration of this PaymentAppConnector.
        :type: PaymentConnectorConfiguration
        """

        self._connector_configuration = connector_configuration
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentAppConnector.

            The date and time when the connector was created.

        :return: The created_on of this PaymentAppConnector.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentAppConnector.

            The date and time when the connector was created.

        :param created_on: The created_on of this PaymentAppConnector.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppConnector.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this PaymentAppConnector.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppConnector.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this PaymentAppConnector.
        :type: str
        """
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentAppConnector.

            A unique identifier for the object.

        :return: The id of this PaymentAppConnector.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentAppConnector.

            A unique identifier for the object.

        :param id: The id of this PaymentAppConnector.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentAppConnector.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentAppConnector.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentAppConnector.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentAppConnector.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppConnector.

            The name used to identify the connector.

        :return: The name of this PaymentAppConnector.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppConnector.

            The name used to identify the connector.

        :param name: The name of this PaymentAppConnector.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_page_endpoint(self):
        """Gets the payment_page_endpoint of this PaymentAppConnector.

            The URL where the user is redirected to process a payment. This endpoint is provided by the external service provider.

        :return: The payment_page_endpoint of this PaymentAppConnector.
        :rtype: str
        """
        return self._payment_page_endpoint

    @payment_page_endpoint.setter
    def payment_page_endpoint(self, payment_page_endpoint):
        """Sets the payment_page_endpoint of this PaymentAppConnector.

            The URL where the user is redirected to process a payment. This endpoint is provided by the external service provider.

        :param payment_page_endpoint: The payment_page_endpoint of this PaymentAppConnector.
        :type: str
        """

        self._payment_page_endpoint = payment_page_endpoint
    
    @property
    def processor(self):
        """Gets the processor of this PaymentAppConnector.

            The payment app processor that the connector belongs to. This relationship is defined when the connector is created.

        :return: The processor of this PaymentAppConnector.
        :rtype: PaymentAppProcessor
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this PaymentAppConnector.

            The payment app processor that the connector belongs to. This relationship is defined when the connector is created.

        :param processor: The processor of this PaymentAppConnector.
        :type: PaymentAppProcessor
        """

        self._processor = processor
    
    @property
    def refund_configuration(self):
        """Gets the refund_configuration of this PaymentAppConnector.

            The refund configuration controlling the behavior for processing refunds. If not present, refunds are not supported for this connector.

        :return: The refund_configuration of this PaymentAppConnector.
        :rtype: PaymentAppRefundConfiguration
        """
        return self._refund_configuration

    @refund_configuration.setter
    def refund_configuration(self, refund_configuration):
        """Sets the refund_configuration of this PaymentAppConnector.

            The refund configuration controlling the behavior for processing refunds. If not present, refunds are not supported for this connector.

        :param refund_configuration: The refund_configuration of this PaymentAppConnector.
        :type: PaymentAppRefundConfiguration
        """

        self._refund_configuration = refund_configuration
    
    @property
    def state(self):
        """Gets the state of this PaymentAppConnector.

            The object's current state.

        :return: The state of this PaymentAppConnector.
        :rtype: PaymentAppConnectorState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentAppConnector.

            The object's current state.

        :param state: The state of this PaymentAppConnector.
        :type: PaymentAppConnectorState
        """

        self._state = state
    
    @property
    def updated_on(self):
        """Gets the updated_on of this PaymentAppConnector.

            The date and time when the connector was last updated.

        :return: The updated_on of this PaymentAppConnector.
        :rtype: datetime
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this PaymentAppConnector.

            The date and time when the connector was last updated.

        :param updated_on: The updated_on of this PaymentAppConnector.
        :type: datetime
        """

        self._updated_on = updated_on
    
    @property
    def version(self):
        """Gets the version of this PaymentAppConnector.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentAppConnector.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentAppConnector.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentAppConnector.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppConnector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppConnector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractTransactionPending:

    swagger_types = {
    
        'allowed_payment_method_brands': 'list[int]',
        'allowed_payment_method_configurations': 'list[int]',
        'billing_address': 'AddressCreate',
        'completion_behavior': 'TransactionCompletionBehavior',
        'currency': 'str',
        'customer_email_address': 'str',
        'customer_id': 'str',
        'failed_url': 'str',
        'invoice_merchant_reference': 'str',
        'language': 'str',
        'line_items': 'list[LineItemCreate]',
        'merchant_reference': 'str',
        'meta_data': 'dict(str, str)',
        'shipping_address': 'AddressCreate',
        'shipping_method': 'str',
        'success_url': 'str',
        'time_zone': 'str',
        'token': 'int',
        'tokenization_mode': 'TokenizationMode',
    }

    attribute_map = {
        'allowed_payment_method_brands': 'allowedPaymentMethodBrands','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','billing_address': 'billingAddress','completion_behavior': 'completionBehavior','currency': 'currency','customer_email_address': 'customerEmailAddress','customer_id': 'customerId','failed_url': 'failedUrl','invoice_merchant_reference': 'invoiceMerchantReference','language': 'language','line_items': 'lineItems','merchant_reference': 'merchantReference','meta_data': 'metaData','shipping_address': 'shippingAddress','shipping_method': 'shippingMethod','success_url': 'successUrl','time_zone': 'timeZone','token': 'token','tokenization_mode': 'tokenizationMode',
    }

    
    _allowed_payment_method_brands = None
    _allowed_payment_method_configurations = None
    _billing_address = None
    _completion_behavior = None
    _currency = None
    _customer_email_address = None
    _customer_id = None
    _failed_url = None
    _invoice_merchant_reference = None
    _language = None
    _line_items = None
    _merchant_reference = None
    _meta_data = None
    _shipping_address = None
    _shipping_method = None
    _success_url = None
    _time_zone = None
    _token = None
    _tokenization_mode = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_brands = kwargs.get('allowed_payment_method_brands', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.completion_behavior = kwargs.get('completion_behavior', None)
        self.currency = kwargs.get('currency', None)
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.failed_url = kwargs.get('failed_url', None)
        self.invoice_merchant_reference = kwargs.get('invoice_merchant_reference', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        self.shipping_method = kwargs.get('shipping_method', None)
        self.success_url = kwargs.get('success_url', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token = kwargs.get('token', None)
        self.tokenization_mode = kwargs.get('tokenization_mode', None)
        

    
    @property
    def allowed_payment_method_brands(self):
        """Gets the allowed_payment_method_brands of this AbstractTransactionPending.

            The payment method brands that can be used to authorize the transaction.

        :return: The allowed_payment_method_brands of this AbstractTransactionPending.
        :rtype: list[int]
        """
        return self._allowed_payment_method_brands

    @allowed_payment_method_brands.setter
    def allowed_payment_method_brands(self, allowed_payment_method_brands):
        """Sets the allowed_payment_method_brands of this AbstractTransactionPending.

            The payment method brands that can be used to authorize the transaction.

        :param allowed_payment_method_brands: The allowed_payment_method_brands of this AbstractTransactionPending.
        :type: list[int]
        """

        self._allowed_payment_method_brands = allowed_payment_method_brands
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this AbstractTransactionPending.

            The payment method configurations that can be used to authorize the transaction.

        :return: The allowed_payment_method_configurations of this AbstractTransactionPending.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this AbstractTransactionPending.

            The payment method configurations that can be used to authorize the transaction.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this AbstractTransactionPending.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def billing_address(self):
        """Gets the billing_address of this AbstractTransactionPending.

            The address associated with the payment method for invoicing and transaction processing purposes.

        :return: The billing_address of this AbstractTransactionPending.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this AbstractTransactionPending.

            The address associated with the payment method for invoicing and transaction processing purposes.

        :param billing_address: The billing_address of this AbstractTransactionPending.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def completion_behavior(self):
        """Gets the completion_behavior of this AbstractTransactionPending.

            The behavior that controls when the transaction is completed.

        :return: The completion_behavior of this AbstractTransactionPending.
        :rtype: TransactionCompletionBehavior
        """
        return self._completion_behavior

    @completion_behavior.setter
    def completion_behavior(self, completion_behavior):
        """Sets the completion_behavior of this AbstractTransactionPending.

            The behavior that controls when the transaction is completed.

        :param completion_behavior: The completion_behavior of this AbstractTransactionPending.
        :type: TransactionCompletionBehavior
        """

        self._completion_behavior = completion_behavior
    
    @property
    def currency(self):
        """Gets the currency of this AbstractTransactionPending.

            The three-letter code (ISO 4217 format) of the transaction's currency.

        :return: The currency of this AbstractTransactionPending.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AbstractTransactionPending.

            The three-letter code (ISO 4217 format) of the transaction's currency.

        :param currency: The currency of this AbstractTransactionPending.
        :type: str
        """

        self._currency = currency
    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this AbstractTransactionPending.

            The customer's email address.

        :return: The customer_email_address of this AbstractTransactionPending.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this AbstractTransactionPending.

            The customer's email address.

        :param customer_email_address: The customer_email_address of this AbstractTransactionPending.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 254:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `254`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this AbstractTransactionPending.

            The unique identifier of the customer in the external system.

        :return: The customer_id of this AbstractTransactionPending.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AbstractTransactionPending.

            The unique identifier of the customer in the external system.

        :param customer_id: The customer_id of this AbstractTransactionPending.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def failed_url(self):
        """Gets the failed_url of this AbstractTransactionPending.

            The URL to redirect the customer back to after they canceled or failed to authenticated their payment.

        :return: The failed_url of this AbstractTransactionPending.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this AbstractTransactionPending.

            The URL to redirect the customer back to after they canceled or failed to authenticated their payment.

        :param failed_url: The failed_url of this AbstractTransactionPending.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 2000:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `2000`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def invoice_merchant_reference(self):
        """Gets the invoice_merchant_reference of this AbstractTransactionPending.

            The merchant's reference used to identify the invoice.

        :return: The invoice_merchant_reference of this AbstractTransactionPending.
        :rtype: str
        """
        return self._invoice_merchant_reference

    @invoice_merchant_reference.setter
    def invoice_merchant_reference(self, invoice_merchant_reference):
        """Sets the invoice_merchant_reference of this AbstractTransactionPending.

            The merchant's reference used to identify the invoice.

        :param invoice_merchant_reference: The invoice_merchant_reference of this AbstractTransactionPending.
        :type: str
        """
        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")

        self._invoice_merchant_reference = invoice_merchant_reference
    
    @property
    def language(self):
        """Gets the language of this AbstractTransactionPending.

            The language that is linked to the object.

        :return: The language of this AbstractTransactionPending.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractTransactionPending.

            The language that is linked to the object.

        :param language: The language of this AbstractTransactionPending.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this AbstractTransactionPending.

            The line items purchased by the customer.

        :return: The line_items of this AbstractTransactionPending.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this AbstractTransactionPending.

            The line items purchased by the customer.

        :param line_items: The line_items of this AbstractTransactionPending.
        :type: list[LineItemCreate]
        """

        self._line_items = line_items
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this AbstractTransactionPending.

            The merchant's reference used to identify the transaction.

        :return: The merchant_reference of this AbstractTransactionPending.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this AbstractTransactionPending.

            The merchant's reference used to identify the transaction.

        :param merchant_reference: The merchant_reference of this AbstractTransactionPending.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def meta_data(self):
        """Gets the meta_data of this AbstractTransactionPending.

            Allow to store additional information about the object.

        :return: The meta_data of this AbstractTransactionPending.
        :rtype: dict(str, str)
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this AbstractTransactionPending.

            Allow to store additional information about the object.

        :param meta_data: The meta_data of this AbstractTransactionPending.
        :type: dict(str, str)
        """

        self._meta_data = meta_data
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this AbstractTransactionPending.

            The address to where the order will be shipped.

        :return: The shipping_address of this AbstractTransactionPending.
        :rtype: AddressCreate
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this AbstractTransactionPending.

            The address to where the order will be shipped.

        :param shipping_address: The shipping_address of this AbstractTransactionPending.
        :type: AddressCreate
        """

        self._shipping_address = shipping_address
    
    @property
    def shipping_method(self):
        """Gets the shipping_method of this AbstractTransactionPending.

            The name of the shipping method used to ship the products.

        :return: The shipping_method of this AbstractTransactionPending.
        :rtype: str
        """
        return self._shipping_method

    @shipping_method.setter
    def shipping_method(self, shipping_method):
        """Sets the shipping_method of this AbstractTransactionPending.

            The name of the shipping method used to ship the products.

        :param shipping_method: The shipping_method of this AbstractTransactionPending.
        :type: str
        """
        if shipping_method is not None and len(shipping_method) > 200:
            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `200`")

        self._shipping_method = shipping_method
    
    @property
    def success_url(self):
        """Gets the success_url of this AbstractTransactionPending.

            The URL to redirect the customer back to after they successfully authenticated their payment.

        :return: The success_url of this AbstractTransactionPending.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this AbstractTransactionPending.

            The URL to redirect the customer back to after they successfully authenticated their payment.

        :param success_url: The success_url of this AbstractTransactionPending.
        :type: str
        """
        if success_url is not None and len(success_url) > 2000:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `2000`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractTransactionPending.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :return: The time_zone of this AbstractTransactionPending.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractTransactionPending.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :param time_zone: The time_zone of this AbstractTransactionPending.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token(self):
        """Gets the token of this AbstractTransactionPending.

            The payment token that should be used to charge the customer.

        :return: The token of this AbstractTransactionPending.
        :rtype: int
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AbstractTransactionPending.

            The payment token that should be used to charge the customer.

        :param token: The token of this AbstractTransactionPending.
        :type: int
        """

        self._token = token
    
    @property
    def tokenization_mode(self):
        """Gets the tokenization_mode of this AbstractTransactionPending.

            The tokenization mode specifies whether and how the tokenization of payment information is applied to the transaction.

        :return: The tokenization_mode of this AbstractTransactionPending.
        :rtype: TokenizationMode
        """
        return self._tokenization_mode

    @tokenization_mode.setter
    def tokenization_mode(self, tokenization_mode):
        """Sets the tokenization_mode of this AbstractTransactionPending.

            The tokenization mode specifies whether and how the tokenization of payment information is applied to the transaction.

        :param tokenization_mode: The tokenization_mode of this AbstractTransactionPending.
        :type: TokenizationMode
        """

        self._tokenization_mode = tokenization_mode
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractTransactionPending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractTransactionPending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentMethodConfiguration:

    swagger_types = {
    
        'data_collection_type': 'DataCollectionType',
        'description': 'dict(str, str)',
        'id': 'int',
        'image_resource_path': 'ResourcePath',
        'linked_space_id': 'int',
        'name': 'str',
        'one_click_payment_mode': 'OneClickPaymentMode',
        'payment_method': 'int',
        'planned_purge_date': 'datetime',
        'resolved_description': 'dict(str, str)',
        'resolved_image_url': 'str',
        'resolved_title': 'dict(str, str)',
        'sort_order': 'int',
        'space_id': 'int',
        'state': 'CreationEntityState',
        'title': 'dict(str, str)',
        'version': 'int',
    }

    attribute_map = {
        'data_collection_type': 'dataCollectionType','description': 'description','id': 'id','image_resource_path': 'imageResourcePath','linked_space_id': 'linkedSpaceId','name': 'name','one_click_payment_mode': 'oneClickPaymentMode','payment_method': 'paymentMethod','planned_purge_date': 'plannedPurgeDate','resolved_description': 'resolvedDescription','resolved_image_url': 'resolvedImageUrl','resolved_title': 'resolvedTitle','sort_order': 'sortOrder','space_id': 'spaceId','state': 'state','title': 'title','version': 'version',
    }

    
    _data_collection_type = None
    _description = None
    _id = None
    _image_resource_path = None
    _linked_space_id = None
    _name = None
    _one_click_payment_mode = None
    _payment_method = None
    _planned_purge_date = None
    _resolved_description = None
    _resolved_image_url = None
    _resolved_title = None
    _sort_order = None
    _space_id = None
    _state = None
    _title = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.data_collection_type = kwargs.get('data_collection_type', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.image_resource_path = kwargs.get('image_resource_path', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.one_click_payment_mode = kwargs.get('one_click_payment_mode', None)
        self.payment_method = kwargs.get('payment_method', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.resolved_description = kwargs.get('resolved_description', None)
        self.resolved_image_url = kwargs.get('resolved_image_url', None)
        self.resolved_title = kwargs.get('resolved_title', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.space_id = kwargs.get('space_id', None)
        self.state = kwargs.get('state', None)
        self.title = kwargs.get('title', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def data_collection_type(self):
        """Gets the data_collection_type of this PaymentMethodConfiguration.

            The data collection type specifies how the payment information is collected.

        :return: The data_collection_type of this PaymentMethodConfiguration.
        :rtype: DataCollectionType
        """
        return self._data_collection_type

    @data_collection_type.setter
    def data_collection_type(self, data_collection_type):
        """Sets the data_collection_type of this PaymentMethodConfiguration.

            The data collection type specifies how the payment information is collected.

        :param data_collection_type: The data_collection_type of this PaymentMethodConfiguration.
        :type: DataCollectionType
        """

        self._data_collection_type = data_collection_type
    
    @property
    def description(self):
        """Gets the description of this PaymentMethodConfiguration.

            A customer-facing custom description for the payment method.

        :return: The description of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentMethodConfiguration.

            A customer-facing custom description for the payment method.

        :param description: The description of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this PaymentMethodConfiguration.

            A unique identifier for the object.

        :return: The id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentMethodConfiguration.

            A unique identifier for the object.

        :param id: The id of this PaymentMethodConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def image_resource_path(self):
        """Gets the image_resource_path of this PaymentMethodConfiguration.

            The resource path to a custom image for the payment method, displayed to the customer for visual identification.

        :return: The image_resource_path of this PaymentMethodConfiguration.
        :rtype: ResourcePath
        """
        return self._image_resource_path

    @image_resource_path.setter
    def image_resource_path(self, image_resource_path):
        """Sets the image_resource_path of this PaymentMethodConfiguration.

            The resource path to a custom image for the payment method, displayed to the customer for visual identification.

        :param image_resource_path: The image_resource_path of this PaymentMethodConfiguration.
        :type: ResourcePath
        """

        self._image_resource_path = image_resource_path
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentMethodConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentMethodConfiguration.

            The name used to identify the payment method configuration.

        :return: The name of this PaymentMethodConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentMethodConfiguration.

            The name used to identify the payment method configuration.

        :param name: The name of this PaymentMethodConfiguration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def one_click_payment_mode(self):
        """Gets the one_click_payment_mode of this PaymentMethodConfiguration.

            The one-click payment mode determines whether the customer can save their payment details for later payments.

        :return: The one_click_payment_mode of this PaymentMethodConfiguration.
        :rtype: OneClickPaymentMode
        """
        return self._one_click_payment_mode

    @one_click_payment_mode.setter
    def one_click_payment_mode(self, one_click_payment_mode):
        """Sets the one_click_payment_mode of this PaymentMethodConfiguration.

            The one-click payment mode determines whether the customer can save their payment details for later payments.

        :param one_click_payment_mode: The one_click_payment_mode of this PaymentMethodConfiguration.
        :type: OneClickPaymentMode
        """

        self._one_click_payment_mode = one_click_payment_mode
    
    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentMethodConfiguration.

            The payment method that the configuration is for.

        :return: The payment_method of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentMethodConfiguration.

            The payment method that the configuration is for.

        :param payment_method: The payment_method of this PaymentMethodConfiguration.
        :type: int
        """

        self._payment_method = payment_method
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentMethodConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentMethodConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentMethodConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentMethodConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def resolved_description(self):
        """Gets the resolved_description of this PaymentMethodConfiguration.

            The description of the payment method displayed to the customer. If a custom description is defined, it will be used; otherwise, the default description of the payment method will be shown.

        :return: The resolved_description of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._resolved_description

    @resolved_description.setter
    def resolved_description(self, resolved_description):
        """Sets the resolved_description of this PaymentMethodConfiguration.

            The description of the payment method displayed to the customer. If a custom description is defined, it will be used; otherwise, the default description of the payment method will be shown.

        :param resolved_description: The resolved_description of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._resolved_description = resolved_description
    
    @property
    def resolved_image_url(self):
        """Gets the resolved_image_url of this PaymentMethodConfiguration.

            The URL to the image of the payment method displayed to the customer. If a custom image is defined, it will be used; otherwise, the default image of the payment method will be shown.

        :return: The resolved_image_url of this PaymentMethodConfiguration.
        :rtype: str
        """
        return self._resolved_image_url

    @resolved_image_url.setter
    def resolved_image_url(self, resolved_image_url):
        """Sets the resolved_image_url of this PaymentMethodConfiguration.

            The URL to the image of the payment method displayed to the customer. If a custom image is defined, it will be used; otherwise, the default image of the payment method will be shown.

        :param resolved_image_url: The resolved_image_url of this PaymentMethodConfiguration.
        :type: str
        """

        self._resolved_image_url = resolved_image_url
    
    @property
    def resolved_title(self):
        """Gets the resolved_title of this PaymentMethodConfiguration.

            The title of the payment method displayed to the customer. If a custom title is defined, it will be used; otherwise, the default title of the payment method will be shown.

        :return: The resolved_title of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._resolved_title

    @resolved_title.setter
    def resolved_title(self, resolved_title):
        """Sets the resolved_title of this PaymentMethodConfiguration.

            The title of the payment method displayed to the customer. If a custom title is defined, it will be used; otherwise, the default title of the payment method will be shown.

        :param resolved_title: The resolved_title of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._resolved_title = resolved_title
    
    @property
    def sort_order(self):
        """Gets the sort_order of this PaymentMethodConfiguration.

            When listing payment methods, they can be sorted by this number.

        :return: The sort_order of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this PaymentMethodConfiguration.

            When listing payment methods, they can be sorted by this number.

        :param sort_order: The sort_order of this PaymentMethodConfiguration.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def space_id(self):
        """Gets the space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :return: The space_id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :param space_id: The space_id of this PaymentMethodConfiguration.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def state(self):
        """Gets the state of this PaymentMethodConfiguration.

            The object's current state.

        :return: The state of this PaymentMethodConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentMethodConfiguration.

            The object's current state.

        :param state: The state of this PaymentMethodConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def title(self):
        """Gets the title of this PaymentMethodConfiguration.

            A customer-facing custom title for the payment method.

        :return: The title of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PaymentMethodConfiguration.

            A customer-facing custom title for the payment method.

        :param title: The title of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._title = title
    
    @property
    def version(self):
        """Gets the version of this PaymentMethodConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentMethodConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentMethodConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentMethodConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentMethodConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductVersion:

    swagger_types = {
    
        'activated_on': 'datetime',
        'billing_cycle': 'str',
        'billing_cycle_model': 'BillingCycleModel',
        'comment': 'str',
        'created_on': 'datetime',
        'default_currency': 'str',
        'enabled_currencies': 'list[str]',
        'id': 'int',
        'increment_number': 'int',
        'linked_space_id': 'int',
        'minimal_number_of_periods': 'int',
        'name': 'dict(str, str)',
        'number_of_notice_periods': 'int',
        'obsoleted_on': 'datetime',
        'planned_purge_date': 'datetime',
        'product': 'SubscriptionProduct',
        'reference': 'str',
        'retiring_finished_on': 'datetime',
        'retiring_started_on': 'datetime',
        'state': 'SubscriptionProductVersionState',
        'tax_calculation': 'TaxCalculation',
        'version': 'int',
    }

    attribute_map = {
        'activated_on': 'activatedOn','billing_cycle': 'billingCycle','billing_cycle_model': 'billingCycleModel','comment': 'comment','created_on': 'createdOn','default_currency': 'defaultCurrency','enabled_currencies': 'enabledCurrencies','id': 'id','increment_number': 'incrementNumber','linked_space_id': 'linkedSpaceId','minimal_number_of_periods': 'minimalNumberOfPeriods','name': 'name','number_of_notice_periods': 'numberOfNoticePeriods','obsoleted_on': 'obsoletedOn','planned_purge_date': 'plannedPurgeDate','product': 'product','reference': 'reference','retiring_finished_on': 'retiringFinishedOn','retiring_started_on': 'retiringStartedOn','state': 'state','tax_calculation': 'taxCalculation','version': 'version',
    }

    
    _activated_on = None
    _billing_cycle = None
    _billing_cycle_model = None
    _comment = None
    _created_on = None
    _default_currency = None
    _enabled_currencies = None
    _id = None
    _increment_number = None
    _linked_space_id = None
    _minimal_number_of_periods = None
    _name = None
    _number_of_notice_periods = None
    _obsoleted_on = None
    _planned_purge_date = None
    _product = None
    _reference = None
    _retiring_finished_on = None
    _retiring_started_on = None
    _state = None
    _tax_calculation = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.activated_on = kwargs.get('activated_on', None)
        self.billing_cycle = kwargs.get('billing_cycle', None)
        self.billing_cycle_model = kwargs.get('billing_cycle_model', None)
        self.comment = kwargs.get('comment', None)
        self.created_on = kwargs.get('created_on', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.enabled_currencies = kwargs.get('enabled_currencies', None)
        self.id = kwargs.get('id', None)
        self.increment_number = kwargs.get('increment_number', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.minimal_number_of_periods = kwargs.get('minimal_number_of_periods', None)
        self.name = kwargs.get('name', None)
        self.number_of_notice_periods = kwargs.get('number_of_notice_periods', None)
        self.obsoleted_on = kwargs.get('obsoleted_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.product = kwargs.get('product', None)
        self.reference = kwargs.get('reference', None)
        self.retiring_finished_on = kwargs.get('retiring_finished_on', None)
        self.retiring_started_on = kwargs.get('retiring_started_on', None)
        self.state = kwargs.get('state', None)
        self.tax_calculation = kwargs.get('tax_calculation', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def activated_on(self):
        """Gets the activated_on of this SubscriptionProductVersion.

            The date and time when the product version was activated.

        :return: The activated_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this SubscriptionProductVersion.

            The date and time when the product version was activated.

        :param activated_on: The activated_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def billing_cycle(self):
        """Gets the billing_cycle of this SubscriptionProductVersion.

            The recurring period of time, typically monthly or annually, for which a subscriber is charged.

        :return: The billing_cycle of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._billing_cycle

    @billing_cycle.setter
    def billing_cycle(self, billing_cycle):
        """Sets the billing_cycle of this SubscriptionProductVersion.

            The recurring period of time, typically monthly or annually, for which a subscriber is charged.

        :param billing_cycle: The billing_cycle of this SubscriptionProductVersion.
        :type: str
        """

        self._billing_cycle = billing_cycle
    
    @property
    def billing_cycle_model(self):
        """Gets the billing_cycle_model of this SubscriptionProductVersion.

            

        :return: The billing_cycle_model of this SubscriptionProductVersion.
        :rtype: BillingCycleModel
        """
        return self._billing_cycle_model

    @billing_cycle_model.setter
    def billing_cycle_model(self, billing_cycle_model):
        """Sets the billing_cycle_model of this SubscriptionProductVersion.

            

        :param billing_cycle_model: The billing_cycle_model of this SubscriptionProductVersion.
        :type: BillingCycleModel
        """

        self._billing_cycle_model = billing_cycle_model
    
    @property
    def comment(self):
        """Gets the comment of this SubscriptionProductVersion.

            A comment that describes the product version and why it was created. It is not disclosed to the subscriber.

        :return: The comment of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SubscriptionProductVersion.

            A comment that describes the product version and why it was created. It is not disclosed to the subscriber.

        :param comment: The comment of this SubscriptionProductVersion.
        :type: str
        """

        self._comment = comment
    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionProductVersion.

            The date and time when the product version was created.

        :return: The created_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionProductVersion.

            The date and time when the product version was created.

        :param created_on: The created_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def default_currency(self):
        """Gets the default_currency of this SubscriptionProductVersion.

            The three-letter code (ISO 4217 format) of the product version's default currency.

        :return: The default_currency of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this SubscriptionProductVersion.

            The three-letter code (ISO 4217 format) of the product version's default currency.

        :param default_currency: The default_currency of this SubscriptionProductVersion.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def enabled_currencies(self):
        """Gets the enabled_currencies of this SubscriptionProductVersion.

            The three-letter codes (ISO 4217 format) of the currencies that the product version supports.

        :return: The enabled_currencies of this SubscriptionProductVersion.
        :rtype: list[str]
        """
        return self._enabled_currencies

    @enabled_currencies.setter
    def enabled_currencies(self, enabled_currencies):
        """Sets the enabled_currencies of this SubscriptionProductVersion.

            The three-letter codes (ISO 4217 format) of the currencies that the product version supports.

        :param enabled_currencies: The enabled_currencies of this SubscriptionProductVersion.
        :type: list[str]
        """

        self._enabled_currencies = enabled_currencies
    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductVersion.

            A unique identifier for the object.

        :return: The id of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductVersion.

            A unique identifier for the object.

        :param id: The id of this SubscriptionProductVersion.
        :type: int
        """

        self._id = id
    
    @property
    def increment_number(self):
        """Gets the increment_number of this SubscriptionProductVersion.

            Whenever a new version of a product is created, the number is increased and assigned.

        :return: The increment_number of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._increment_number

    @increment_number.setter
    def increment_number(self, increment_number):
        """Sets the increment_number of this SubscriptionProductVersion.

            Whenever a new version of a product is created, the number is increased and assigned.

        :param increment_number: The increment_number of this SubscriptionProductVersion.
        :type: int
        """

        self._increment_number = increment_number
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionProductVersion.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionProductVersion.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionProductVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def minimal_number_of_periods(self):
        """Gets the minimal_number_of_periods of this SubscriptionProductVersion.

            The minimum number of periods the subscription will run before it can be terminated.

        :return: The minimal_number_of_periods of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._minimal_number_of_periods

    @minimal_number_of_periods.setter
    def minimal_number_of_periods(self, minimal_number_of_periods):
        """Sets the minimal_number_of_periods of this SubscriptionProductVersion.

            The minimum number of periods the subscription will run before it can be terminated.

        :param minimal_number_of_periods: The minimal_number_of_periods of this SubscriptionProductVersion.
        :type: int
        """

        self._minimal_number_of_periods = minimal_number_of_periods
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductVersion.

            The localized name of the product that is displayed to the customer.

        :return: The name of this SubscriptionProductVersion.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductVersion.

            The localized name of the product that is displayed to the customer.

        :param name: The name of this SubscriptionProductVersion.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def number_of_notice_periods(self):
        """Gets the number_of_notice_periods of this SubscriptionProductVersion.

            The number of periods the subscription will keep running after its termination was requested.

        :return: The number_of_notice_periods of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._number_of_notice_periods

    @number_of_notice_periods.setter
    def number_of_notice_periods(self, number_of_notice_periods):
        """Sets the number_of_notice_periods of this SubscriptionProductVersion.

            The number of periods the subscription will keep running after its termination was requested.

        :param number_of_notice_periods: The number_of_notice_periods of this SubscriptionProductVersion.
        :type: int
        """

        self._number_of_notice_periods = number_of_notice_periods
    
    @property
    def obsoleted_on(self):
        """Gets the obsoleted_on of this SubscriptionProductVersion.

            The date and time when the product version was made obsolete.

        :return: The obsoleted_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._obsoleted_on

    @obsoleted_on.setter
    def obsoleted_on(self, obsoleted_on):
        """Sets the obsoleted_on of this SubscriptionProductVersion.

            The date and time when the product version was made obsolete.

        :param obsoleted_on: The obsoleted_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._obsoleted_on = obsoleted_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionProductVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionProductVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionProductVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def product(self):
        """Gets the product of this SubscriptionProductVersion.

            The product that the version belongs to.

        :return: The product of this SubscriptionProductVersion.
        :rtype: SubscriptionProduct
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionProductVersion.

            The product that the version belongs to.

        :param product: The product of this SubscriptionProductVersion.
        :type: SubscriptionProduct
        """

        self._product = product
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionProductVersion.

            The reference used to identify the product version.

        :return: The reference of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionProductVersion.

            The reference used to identify the product version.

        :param reference: The reference of this SubscriptionProductVersion.
        :type: str
        """
        if reference is not None and len(reference) > 125:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `125`")

        self._reference = reference
    
    @property
    def retiring_finished_on(self):
        """Gets the retiring_finished_on of this SubscriptionProductVersion.

            The date and time when the product version was retired.

        :return: The retiring_finished_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._retiring_finished_on

    @retiring_finished_on.setter
    def retiring_finished_on(self, retiring_finished_on):
        """Sets the retiring_finished_on of this SubscriptionProductVersion.

            The date and time when the product version was retired.

        :param retiring_finished_on: The retiring_finished_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._retiring_finished_on = retiring_finished_on
    
    @property
    def retiring_started_on(self):
        """Gets the retiring_started_on of this SubscriptionProductVersion.

            The date and time when the product version's retirement was started.

        :return: The retiring_started_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._retiring_started_on

    @retiring_started_on.setter
    def retiring_started_on(self, retiring_started_on):
        """Sets the retiring_started_on of this SubscriptionProductVersion.

            The date and time when the product version's retirement was started.

        :param retiring_started_on: The retiring_started_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._retiring_started_on = retiring_started_on
    
    @property
    def state(self):
        """Gets the state of this SubscriptionProductVersion.

            The object's current state.

        :return: The state of this SubscriptionProductVersion.
        :rtype: SubscriptionProductVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionProductVersion.

            The object's current state.

        :param state: The state of this SubscriptionProductVersion.
        :type: SubscriptionProductVersionState
        """

        self._state = state
    
    @property
    def tax_calculation(self):
        """Gets the tax_calculation of this SubscriptionProductVersion.

            The way taxes are calculated for fees.

        :return: The tax_calculation of this SubscriptionProductVersion.
        :rtype: TaxCalculation
        """
        return self._tax_calculation

    @tax_calculation.setter
    def tax_calculation(self, tax_calculation):
        """Sets the tax_calculation of this SubscriptionProductVersion.

            The way taxes are calculated for fees.

        :param tax_calculation: The tax_calculation of this SubscriptionProductVersion.
        :type: TaxCalculation
        """

        self._tax_calculation = tax_calculation
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionProductVersion.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class PanType(Enum):
    
    PLAIN = "PLAIN"
    PLAIN_GOOGLE_PAY = "PLAIN_GOOGLE_PAY"
    SCHEME_TOKEN = "SCHEME_TOKEN"
    SCHEME_TOKEN_CLICK_TO_PAY = "SCHEME_TOKEN_CLICK_TO_PAY"
    DEVICE_TOKEN_APPLE_PAY = "DEVICE_TOKEN_APPLE_PAY"
    DEVICE_TOKEN_GOOGLE_PAY = "DEVICE_TOKEN_GOOGLE_PAY"
    DEVICE_TOKEN_SAMSUNG_PAY = "DEVICE_TOKEN_SAMSUNG_PAY"
    DEVICE_TOKEN_ANDROID_PAY = "DEVICE_TOKEN_ANDROID_PAY"




# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductComponent:

    swagger_types = {
    
        'component_change_weight': 'int',
        'component_group': 'SubscriptionProductComponentGroup',
        'default_component': 'bool',
        'description': 'dict(str, str)',
        'id': 'int',
        'linked_space_id': 'int',
        'maximal_quantity': 'float',
        'minimal_quantity': 'float',
        'name': 'dict(str, str)',
        'quantity_step': 'float',
        'reference': 'SubscriptionProductComponentReference',
        'sort_order': 'int',
        'tax_class': 'TaxClass',
        'version': 'int',
    }

    attribute_map = {
        'component_change_weight': 'componentChangeWeight','component_group': 'componentGroup','default_component': 'defaultComponent','description': 'description','id': 'id','linked_space_id': 'linkedSpaceId','maximal_quantity': 'maximalQuantity','minimal_quantity': 'minimalQuantity','name': 'name','quantity_step': 'quantityStep','reference': 'reference','sort_order': 'sortOrder','tax_class': 'taxClass','version': 'version',
    }

    
    _component_change_weight = None
    _component_group = None
    _default_component = None
    _description = None
    _id = None
    _linked_space_id = None
    _maximal_quantity = None
    _minimal_quantity = None
    _name = None
    _quantity_step = None
    _reference = None
    _sort_order = None
    _tax_class = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.component_change_weight = kwargs.get('component_change_weight', None)
        self.component_group = kwargs.get('component_group', None)
        self.default_component = kwargs.get('default_component', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maximal_quantity = kwargs.get('maximal_quantity', None)
        self.minimal_quantity = kwargs.get('minimal_quantity', None)
        self.name = kwargs.get('name', None)
        self.quantity_step = kwargs.get('quantity_step', None)
        self.reference = kwargs.get('reference', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.tax_class = kwargs.get('tax_class', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def component_change_weight(self):
        """Gets the component_change_weight of this SubscriptionProductComponent.

            If switching from a component with a lower tier to a component with a higher one, this is considered an upgrade and a fee may be applied.

        :return: The component_change_weight of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._component_change_weight

    @component_change_weight.setter
    def component_change_weight(self, component_change_weight):
        """Sets the component_change_weight of this SubscriptionProductComponent.

            If switching from a component with a lower tier to a component with a higher one, this is considered an upgrade and a fee may be applied.

        :param component_change_weight: The component_change_weight of this SubscriptionProductComponent.
        :type: int
        """

        self._component_change_weight = component_change_weight
    
    @property
    def component_group(self):
        """Gets the component_group of this SubscriptionProductComponent.

            The group that the component belongs to.

        :return: The component_group of this SubscriptionProductComponent.
        :rtype: SubscriptionProductComponentGroup
        """
        return self._component_group

    @component_group.setter
    def component_group(self, component_group):
        """Sets the component_group of this SubscriptionProductComponent.

            The group that the component belongs to.

        :param component_group: The component_group of this SubscriptionProductComponent.
        :type: SubscriptionProductComponentGroup
        """

        self._component_group = component_group
    
    @property
    def default_component(self):
        """Gets the default_component of this SubscriptionProductComponent.

            Whether this is the default component in its group and preselected.

        :return: The default_component of this SubscriptionProductComponent.
        :rtype: bool
        """
        return self._default_component

    @default_component.setter
    def default_component(self, default_component):
        """Sets the default_component of this SubscriptionProductComponent.

            Whether this is the default component in its group and preselected.

        :param default_component: The default_component of this SubscriptionProductComponent.
        :type: bool
        """

        self._default_component = default_component
    
    @property
    def description(self):
        """Gets the description of this SubscriptionProductComponent.

            The localized description of the component that is displayed to the customer.

        :return: The description of this SubscriptionProductComponent.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionProductComponent.

            The localized description of the component that is displayed to the customer.

        :param description: The description of this SubscriptionProductComponent.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductComponent.

            A unique identifier for the object.

        :return: The id of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductComponent.

            A unique identifier for the object.

        :param id: The id of this SubscriptionProductComponent.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionProductComponent.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionProductComponent.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionProductComponent.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maximal_quantity(self):
        """Gets the maximal_quantity of this SubscriptionProductComponent.

            A maximum of the defined quantity can be selected for this component.

        :return: The maximal_quantity of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._maximal_quantity

    @maximal_quantity.setter
    def maximal_quantity(self, maximal_quantity):
        """Sets the maximal_quantity of this SubscriptionProductComponent.

            A maximum of the defined quantity can be selected for this component.

        :param maximal_quantity: The maximal_quantity of this SubscriptionProductComponent.
        :type: float
        """

        self._maximal_quantity = maximal_quantity
    
    @property
    def minimal_quantity(self):
        """Gets the minimal_quantity of this SubscriptionProductComponent.

            A minimum of the defined quantity must be selected for this component.

        :return: The minimal_quantity of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._minimal_quantity

    @minimal_quantity.setter
    def minimal_quantity(self, minimal_quantity):
        """Sets the minimal_quantity of this SubscriptionProductComponent.

            A minimum of the defined quantity must be selected for this component.

        :param minimal_quantity: The minimal_quantity of this SubscriptionProductComponent.
        :type: float
        """

        self._minimal_quantity = minimal_quantity
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductComponent.

            The localized name of the component that is displayed to the customer.

        :return: The name of this SubscriptionProductComponent.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductComponent.

            The localized name of the component that is displayed to the customer.

        :param name: The name of this SubscriptionProductComponent.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def quantity_step(self):
        """Gets the quantity_step of this SubscriptionProductComponent.

            The quantity step determines the interval in which the quantity can be increased.

        :return: The quantity_step of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._quantity_step

    @quantity_step.setter
    def quantity_step(self, quantity_step):
        """Sets the quantity_step of this SubscriptionProductComponent.

            The quantity step determines the interval in which the quantity can be increased.

        :param quantity_step: The quantity_step of this SubscriptionProductComponent.
        :type: float
        """

        self._quantity_step = quantity_step
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionProductComponent.

            The reference is used to link components across different product versions.

        :return: The reference of this SubscriptionProductComponent.
        :rtype: SubscriptionProductComponentReference
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionProductComponent.

            The reference is used to link components across different product versions.

        :param reference: The reference of this SubscriptionProductComponent.
        :type: SubscriptionProductComponentReference
        """

        self._reference = reference
    
    @property
    def sort_order(self):
        """Gets the sort_order of this SubscriptionProductComponent.

            When listing components, they can be sorted by this number.

        :return: The sort_order of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this SubscriptionProductComponent.

            When listing components, they can be sorted by this number.

        :param sort_order: The sort_order of this SubscriptionProductComponent.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def tax_class(self):
        """Gets the tax_class of this SubscriptionProductComponent.

            The tax class to be applied to fees.

        :return: The tax_class of this SubscriptionProductComponent.
        :rtype: TaxClass
        """
        return self._tax_class

    @tax_class.setter
    def tax_class(self, tax_class):
        """Sets the tax_class of this SubscriptionProductComponent.

            The tax class to be applied to fees.

        :param tax_class: The tax_class of this SubscriptionProductComponent.
        :type: TaxClass
        """

        self._tax_class = tax_class
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductComponent.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductComponent.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionProductComponent.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductComponent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductComponent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractDebtCollectionCaseUpdate:

    swagger_types = {
    
        'billing_address': 'AddressCreate',
        'contract_date': 'datetime',
        'currency': 'str',
        'due_date': 'datetime',
        'environment': 'DebtCollectionEnvironment',
        'language': 'str',
        'line_items': 'list[LineItemCreate]',
        'space_view_id': 'int',
    }

    attribute_map = {
        'billing_address': 'billingAddress','contract_date': 'contractDate','currency': 'currency','due_date': 'dueDate','environment': 'environment','language': 'language','line_items': 'lineItems','space_view_id': 'spaceViewId',
    }

    
    _billing_address = None
    _contract_date = None
    _currency = None
    _due_date = None
    _environment = None
    _language = None
    _line_items = None
    _space_view_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address', None)
        self.contract_date = kwargs.get('contract_date', None)
        self.currency = kwargs.get('currency', None)
        self.due_date = kwargs.get('due_date', None)
        self.environment = kwargs.get('environment', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this AbstractDebtCollectionCaseUpdate.

            The billing address that identifies the debtor.

        :return: The billing_address of this AbstractDebtCollectionCaseUpdate.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this AbstractDebtCollectionCaseUpdate.

            The billing address that identifies the debtor.

        :param billing_address: The billing_address of this AbstractDebtCollectionCaseUpdate.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def contract_date(self):
        """Gets the contract_date of this AbstractDebtCollectionCaseUpdate.

            The date and time when the contract with the debtor was signed.

        :return: The contract_date of this AbstractDebtCollectionCaseUpdate.
        :rtype: datetime
        """
        return self._contract_date

    @contract_date.setter
    def contract_date(self, contract_date):
        """Sets the contract_date of this AbstractDebtCollectionCaseUpdate.

            The date and time when the contract with the debtor was signed.

        :param contract_date: The contract_date of this AbstractDebtCollectionCaseUpdate.
        :type: datetime
        """

        self._contract_date = contract_date
    
    @property
    def currency(self):
        """Gets the currency of this AbstractDebtCollectionCaseUpdate.

            The three-letter code (ISO 4217 format) of the case's currency.

        :return: The currency of this AbstractDebtCollectionCaseUpdate.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AbstractDebtCollectionCaseUpdate.

            The three-letter code (ISO 4217 format) of the case's currency.

        :param currency: The currency of this AbstractDebtCollectionCaseUpdate.
        :type: str
        """

        self._currency = currency
    
    @property
    def due_date(self):
        """Gets the due_date of this AbstractDebtCollectionCaseUpdate.

            The date and time when the claim was due.

        :return: The due_date of this AbstractDebtCollectionCaseUpdate.
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this AbstractDebtCollectionCaseUpdate.

            The date and time when the claim was due.

        :param due_date: The due_date of this AbstractDebtCollectionCaseUpdate.
        :type: datetime
        """

        self._due_date = due_date
    
    @property
    def environment(self):
        """Gets the environment of this AbstractDebtCollectionCaseUpdate.

            The environment in which the case is processed.

        :return: The environment of this AbstractDebtCollectionCaseUpdate.
        :rtype: DebtCollectionEnvironment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this AbstractDebtCollectionCaseUpdate.

            The environment in which the case is processed.

        :param environment: The environment of this AbstractDebtCollectionCaseUpdate.
        :type: DebtCollectionEnvironment
        """

        self._environment = environment
    
    @property
    def language(self):
        """Gets the language of this AbstractDebtCollectionCaseUpdate.

            The language that is linked to the object.

        :return: The language of this AbstractDebtCollectionCaseUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractDebtCollectionCaseUpdate.

            The language that is linked to the object.

        :param language: The language of this AbstractDebtCollectionCaseUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this AbstractDebtCollectionCaseUpdate.

            The line items that are subject of this debt collection case.

        :return: The line_items of this AbstractDebtCollectionCaseUpdate.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this AbstractDebtCollectionCaseUpdate.

            The line items that are subject of this debt collection case.

        :param line_items: The line_items of this AbstractDebtCollectionCaseUpdate.
        :type: list[LineItemCreate]
        """

        self._line_items = line_items
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this AbstractDebtCollectionCaseUpdate.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this AbstractDebtCollectionCaseUpdate.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this AbstractDebtCollectionCaseUpdate.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this AbstractDebtCollectionCaseUpdate.
        :type: int
        """

        self._space_view_id = space_view_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractDebtCollectionCaseUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractDebtCollectionCaseUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class DisplayableMonth(Enum):
    
    JANUARY = "JANUARY"
    FEBRUARY = "FEBRUARY"
    MARCH = "MARCH"
    APRIL = "APRIL"
    MAY = "MAY"
    JUNE = "JUNE"
    JULY = "JULY"
    AUGUST = "AUGUST"
    SEPTEMBER = "SEPTEMBER"
    OCTOBER = "OCTOBER"
    NOVEMBER = "NOVEMBER"
    DECEMBER = "DECEMBER"




# coding: utf-8
import pprint
import six
from enum import Enum



class Charge:

    swagger_types = {
    
        'created_on': 'datetime',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'space_view_id': 'int',
        'state': 'ChargeState',
        'time_zone': 'str',
        'timeout_on': 'datetime',
        'transaction': 'Transaction',
        'type': 'ChargeType',
        'user_failure_message': 'str',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','failure_reason': 'failureReason','id': 'id','language': 'language','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','space_view_id': 'spaceViewId','state': 'state','time_zone': 'timeZone','timeout_on': 'timeoutOn','transaction': 'transaction','type': 'type','user_failure_message': 'userFailureMessage','version': 'version',
    }

    
    _created_on = None
    _failure_reason = None
    _id = None
    _language = None
    _linked_space_id = None
    _planned_purge_date = None
    _space_view_id = None
    _state = None
    _time_zone = None
    _timeout_on = None
    _transaction = None
    _type = None
    _user_failure_message = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.transaction = kwargs.get('transaction', None)
        self.type = kwargs.get('type', None)
        self.user_failure_message = kwargs.get('user_failure_message', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this Charge.

            The date and time when the object was created.

        :return: The created_on of this Charge.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Charge.

            The date and time when the object was created.

        :param created_on: The created_on of this Charge.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this Charge.

            The reason for the failure of the charge.

        :return: The failure_reason of this Charge.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this Charge.

            The reason for the failure of the charge.

        :param failure_reason: The failure_reason of this Charge.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this Charge.

            A unique identifier for the object.

        :return: The id of this Charge.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Charge.

            A unique identifier for the object.

        :param id: The id of this Charge.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this Charge.

            The language that is linked to the object.

        :return: The language of this Charge.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Charge.

            The language that is linked to the object.

        :param language: The language of this Charge.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Charge.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this Charge.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Charge.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this Charge.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Charge.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this Charge.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Charge.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this Charge.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this Charge.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this Charge.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this Charge.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this Charge.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this Charge.

            The object's current state.

        :return: The state of this Charge.
        :rtype: ChargeState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Charge.

            The object's current state.

        :param state: The state of this Charge.
        :type: ChargeState
        """

        self._state = state
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Charge.

            The time zone that this object is associated with.

        :return: The time_zone of this Charge.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Charge.

            The time zone that this object is associated with.

        :param time_zone: The time_zone of this Charge.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this Charge.

            The date and time when the charge will expire.

        :return: The timeout_on of this Charge.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this Charge.

            The date and time when the charge will expire.

        :param timeout_on: The timeout_on of this Charge.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def transaction(self):
        """Gets the transaction of this Charge.

            The transaction that the charge belongs to.

        :return: The transaction of this Charge.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this Charge.

            The transaction that the charge belongs to.

        :param transaction: The transaction of this Charge.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def type(self):
        """Gets the type of this Charge.

            The type specifying how the customer was charged.

        :return: The type of this Charge.
        :rtype: ChargeType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Charge.

            The type specifying how the customer was charged.

        :param type: The type of this Charge.
        :type: ChargeType
        """

        self._type = type
    
    @property
    def user_failure_message(self):
        """Gets the user_failure_message of this Charge.

            The message that can be displayed to the customer explaining why the charge failed, in the customer's language.

        :return: The user_failure_message of this Charge.
        :rtype: str
        """
        return self._user_failure_message

    @user_failure_message.setter
    def user_failure_message(self, user_failure_message):
        """Sets the user_failure_message of this Charge.

            The message that can be displayed to the customer explaining why the charge failed, in the customer's language.

        :param user_failure_message: The user_failure_message of this Charge.
        :type: str
        """

        self._user_failure_message = user_failure_message
    
    @property
    def version(self):
        """Gets the version of this Charge.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this Charge.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Charge.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this Charge.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Charge, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Charge):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractTokenUpdate:

    swagger_types = {
    
        'customer_email_address': 'str',
        'customer_id': 'str',
        'enabled_for_one_click_payment': 'bool',
        'language': 'str',
        'time_zone': 'str',
        'token_reference': 'str',
    }

    attribute_map = {
        'customer_email_address': 'customerEmailAddress','customer_id': 'customerId','enabled_for_one_click_payment': 'enabledForOneClickPayment','language': 'language','time_zone': 'timeZone','token_reference': 'tokenReference',
    }

    
    _customer_email_address = None
    _customer_id = None
    _enabled_for_one_click_payment = None
    _language = None
    _time_zone = None
    _token_reference = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.enabled_for_one_click_payment = kwargs.get('enabled_for_one_click_payment', None)
        self.language = kwargs.get('language', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token_reference = kwargs.get('token_reference', None)
        

    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this AbstractTokenUpdate.

            The customer's email address.

        :return: The customer_email_address of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this AbstractTokenUpdate.

            The customer's email address.

        :param customer_email_address: The customer_email_address of this AbstractTokenUpdate.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 150:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `150`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this AbstractTokenUpdate.

            The unique identifier of the customer in the external system.

        :return: The customer_id of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AbstractTokenUpdate.

            The unique identifier of the customer in the external system.

        :param customer_id: The customer_id of this AbstractTokenUpdate.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def enabled_for_one_click_payment(self):
        """Gets the enabled_for_one_click_payment of this AbstractTokenUpdate.

            Whether the token is enabled for one-click payments, which simplify the payment process for the customer. One-click tokens are linked to customers via the customer ID.

        :return: The enabled_for_one_click_payment of this AbstractTokenUpdate.
        :rtype: bool
        """
        return self._enabled_for_one_click_payment

    @enabled_for_one_click_payment.setter
    def enabled_for_one_click_payment(self, enabled_for_one_click_payment):
        """Sets the enabled_for_one_click_payment of this AbstractTokenUpdate.

            Whether the token is enabled for one-click payments, which simplify the payment process for the customer. One-click tokens are linked to customers via the customer ID.

        :param enabled_for_one_click_payment: The enabled_for_one_click_payment of this AbstractTokenUpdate.
        :type: bool
        """

        self._enabled_for_one_click_payment = enabled_for_one_click_payment
    
    @property
    def language(self):
        """Gets the language of this AbstractTokenUpdate.

            The language that is linked to the object.

        :return: The language of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractTokenUpdate.

            The language that is linked to the object.

        :param language: The language of this AbstractTokenUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractTokenUpdate.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :return: The time_zone of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractTokenUpdate.

            The customer's time zone, which affects how dates and times are formatted when communicating with the customer.

        :param time_zone: The time_zone of this AbstractTokenUpdate.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token_reference(self):
        """Gets the token_reference of this AbstractTokenUpdate.

            The reference used to identify the payment token (e.g. the customer's ID or email address).

        :return: The token_reference of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._token_reference

    @token_reference.setter
    def token_reference(self, token_reference):
        """Sets the token_reference of this AbstractTokenUpdate.

            The reference used to identify the payment token (e.g. the customer's ID or email address).

        :param token_reference: The token_reference of this AbstractTokenUpdate.
        :type: str
        """
        if token_reference is not None and len(token_reference) > 100:
            raise ValueError("Invalid value for `token_reference`, length must be less than or equal to `100`")

        self._token_reference = token_reference
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractTokenUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractTokenUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminal:

    swagger_types = {
    
        'configuration_version': 'PaymentTerminalConfigurationVersion',
        'default_currency': 'str',
        'device_name': 'str',
        'device_serial_number': 'str',
        'external_id': 'str',
        'id': 'int',
        'identifier': 'str',
        'linked_space_id': 'int',
        'location_version': 'PaymentTerminalLocationVersion',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'state': 'PaymentTerminalState',
        'type': 'PaymentTerminalType',
        'version': 'int',
    }

    attribute_map = {
        'configuration_version': 'configurationVersion','default_currency': 'defaultCurrency','device_name': 'deviceName','device_serial_number': 'deviceSerialNumber','external_id': 'externalId','id': 'id','identifier': 'identifier','linked_space_id': 'linkedSpaceId','location_version': 'locationVersion','name': 'name','planned_purge_date': 'plannedPurgeDate','state': 'state','type': 'type','version': 'version',
    }

    
    _configuration_version = None
    _default_currency = None
    _device_name = None
    _device_serial_number = None
    _external_id = None
    _id = None
    _identifier = None
    _linked_space_id = None
    _location_version = None
    _name = None
    _planned_purge_date = None
    _state = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration_version = kwargs.get('configuration_version', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.device_name = kwargs.get('device_name', None)
        self.device_serial_number = kwargs.get('device_serial_number', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.identifier = kwargs.get('identifier', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.location_version = kwargs.get('location_version', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def configuration_version(self):
        """Gets the configuration_version of this PaymentTerminal.

            The configuration that is assigned to the terminal and determines how it works.

        :return: The configuration_version of this PaymentTerminal.
        :rtype: PaymentTerminalConfigurationVersion
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """Sets the configuration_version of this PaymentTerminal.

            The configuration that is assigned to the terminal and determines how it works.

        :param configuration_version: The configuration_version of this PaymentTerminal.
        :type: PaymentTerminalConfigurationVersion
        """

        self._configuration_version = configuration_version
    
    @property
    def default_currency(self):
        """Gets the default_currency of this PaymentTerminal.

            The default currency of the terminal.

        :return: The default_currency of this PaymentTerminal.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this PaymentTerminal.

            The default currency of the terminal.

        :param default_currency: The default_currency of this PaymentTerminal.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def device_name(self):
        """Gets the device_name of this PaymentTerminal.

            The name of the device that is currently linked to the payment terminal.

        :return: The device_name of this PaymentTerminal.
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this PaymentTerminal.

            The name of the device that is currently linked to the payment terminal.

        :param device_name: The device_name of this PaymentTerminal.
        :type: str
        """

        self._device_name = device_name
    
    @property
    def device_serial_number(self):
        """Gets the device_serial_number of this PaymentTerminal.

            The serial number of the device that is currently linked to the payment terminal.

        :return: The device_serial_number of this PaymentTerminal.
        :rtype: str
        """
        return self._device_serial_number

    @device_serial_number.setter
    def device_serial_number(self, device_serial_number):
        """Sets the device_serial_number of this PaymentTerminal.

            The serial number of the device that is currently linked to the payment terminal.

        :param device_serial_number: The device_serial_number of this PaymentTerminal.
        :type: str
        """

        self._device_serial_number = device_serial_number
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentTerminal.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this PaymentTerminal.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentTerminal.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this PaymentTerminal.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminal.

            A unique identifier for the object.

        :return: The id of this PaymentTerminal.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminal.

            A unique identifier for the object.

        :param id: The id of this PaymentTerminal.
        :type: int
        """

        self._id = id
    
    @property
    def identifier(self):
        """Gets the identifier of this PaymentTerminal.

            The unique identifier of the terminal, that is displayed on the device.

        :return: The identifier of this PaymentTerminal.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this PaymentTerminal.

            The unique identifier of the terminal, that is displayed on the device.

        :param identifier: The identifier of this PaymentTerminal.
        :type: str
        """

        self._identifier = identifier
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminal.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentTerminal.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminal.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminal.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def location_version(self):
        """Gets the location_version of this PaymentTerminal.

            The physical location where the terminal is used.

        :return: The location_version of this PaymentTerminal.
        :rtype: PaymentTerminalLocationVersion
        """
        return self._location_version

    @location_version.setter
    def location_version(self, location_version):
        """Sets the location_version of this PaymentTerminal.

            The physical location where the terminal is used.

        :param location_version: The location_version of this PaymentTerminal.
        :type: PaymentTerminalLocationVersion
        """

        self._location_version = location_version
    
    @property
    def name(self):
        """Gets the name of this PaymentTerminal.

            The name used to identify the payment terminal.

        :return: The name of this PaymentTerminal.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentTerminal.

            The name used to identify the payment terminal.

        :param name: The name of this PaymentTerminal.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentTerminal.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentTerminal.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentTerminal.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentTerminal.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this PaymentTerminal.

            The object's current state.

        :return: The state of this PaymentTerminal.
        :rtype: PaymentTerminalState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentTerminal.

            The object's current state.

        :param state: The state of this PaymentTerminal.
        :type: PaymentTerminalState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this PaymentTerminal.

            The type of the payment terminal.

        :return: The type of this PaymentTerminal.
        :rtype: PaymentTerminalType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PaymentTerminal.

            The type of the payment terminal.

        :param type: The type of this PaymentTerminal.
        :type: PaymentTerminalType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminal.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentTerminal.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminal.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentTerminal.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class DunningCaseLevelState(Enum):
    
    INITIALIZING = "INITIALIZING"
    PENDING = "PENDING"
    FAILED = "FAILED"
    CANCELED = "CANCELED"
    SUCCEEDED = "SUCCEEDED"




# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractSubscriptionProductActive:

    swagger_types = {
    
        'allowed_payment_method_configurations': 'list[int]',
        'failed_payment_suspension_period': 'str',
        'name': 'str',
        'product_locked': 'bool',
        'sort_order': 'int',
        'state': 'SubscriptionProductState',
    }

    attribute_map = {
        'allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','failed_payment_suspension_period': 'failedPaymentSuspensionPeriod','name': 'name','product_locked': 'productLocked','sort_order': 'sortOrder','state': 'state',
    }

    
    _allowed_payment_method_configurations = None
    _failed_payment_suspension_period = None
    _name = None
    _product_locked = None
    _sort_order = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.failed_payment_suspension_period = kwargs.get('failed_payment_suspension_period', None)
        self.name = kwargs.get('name', None)
        self.product_locked = kwargs.get('product_locked', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this AbstractSubscriptionProductActive.

            The payment methods that can be used to subscribe to this product. If none are selected, no restriction is applied.

        :return: The allowed_payment_method_configurations of this AbstractSubscriptionProductActive.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this AbstractSubscriptionProductActive.

            The payment methods that can be used to subscribe to this product. If none are selected, no restriction is applied.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this AbstractSubscriptionProductActive.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def failed_payment_suspension_period(self):
        """Gets the failed_payment_suspension_period of this AbstractSubscriptionProductActive.

            The period after which a subscription that has been suspended due to a failed payment is terminated.

        :return: The failed_payment_suspension_period of this AbstractSubscriptionProductActive.
        :rtype: str
        """
        return self._failed_payment_suspension_period

    @failed_payment_suspension_period.setter
    def failed_payment_suspension_period(self, failed_payment_suspension_period):
        """Sets the failed_payment_suspension_period of this AbstractSubscriptionProductActive.

            The period after which a subscription that has been suspended due to a failed payment is terminated.

        :param failed_payment_suspension_period: The failed_payment_suspension_period of this AbstractSubscriptionProductActive.
        :type: str
        """

        self._failed_payment_suspension_period = failed_payment_suspension_period
    
    @property
    def name(self):
        """Gets the name of this AbstractSubscriptionProductActive.

            The name used to identify the product.

        :return: The name of this AbstractSubscriptionProductActive.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractSubscriptionProductActive.

            The name used to identify the product.

        :param name: The name of this AbstractSubscriptionProductActive.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def product_locked(self):
        """Gets the product_locked of this AbstractSubscriptionProductActive.

            Whether subscriptions can be switched to or from this product, or whether they are locked in.

        :return: The product_locked of this AbstractSubscriptionProductActive.
        :rtype: bool
        """
        return self._product_locked

    @product_locked.setter
    def product_locked(self, product_locked):
        """Sets the product_locked of this AbstractSubscriptionProductActive.

            Whether subscriptions can be switched to or from this product, or whether they are locked in.

        :param product_locked: The product_locked of this AbstractSubscriptionProductActive.
        :type: bool
        """

        self._product_locked = product_locked
    
    @property
    def sort_order(self):
        """Gets the sort_order of this AbstractSubscriptionProductActive.

            When listing products, they can be sorted by this number.

        :return: The sort_order of this AbstractSubscriptionProductActive.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this AbstractSubscriptionProductActive.

            When listing products, they can be sorted by this number.

        :param sort_order: The sort_order of this AbstractSubscriptionProductActive.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def state(self):
        """Gets the state of this AbstractSubscriptionProductActive.

            The object's current state.

        :return: The state of this AbstractSubscriptionProductActive.
        :rtype: SubscriptionProductState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractSubscriptionProductActive.

            The object's current state.

        :param state: The state of this AbstractSubscriptionProductActive.
        :type: SubscriptionProductState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractSubscriptionProductActive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractSubscriptionProductActive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
